OS-style status codes and small conversion helpers. Small OS-style status codes.
Many kernels prefer returning small integer status codes rather than rich error types. This module provides:
crate::status::Status: a compactrepr(i32)enum.crate::status::KResult: aResult<T, Status>alias.- Helper traits to convert common types into status codes.
Enums
- Status
- Compact status codes commonly used in OS code.
Traits
- Into
Status - Converts a value into
Statususing a caller-provided error code. - Option
Into Status - Converts an
Optioninto aKResult.
Type Aliases
- KResult
- Kernel-style result type.