Once

Struct Once 

pub struct Once<T> { /* private fields */ }
A minimal, spin-based Once initializer.

This type is useful for global singletons in no_std environments. It supports one-time initialization with call_once.

State machine

  • 0: uninitialized
  • 1: initialization in progress
  • 2: initialized

Implementations

Source

impl<T> Once<T>

pub const fn new() -> Self

Creates a new uninitialized cell.

pub fn is_initialized(&self) -> bool

Returns true if the value has been initialized.

pub fn get(&self) -> Option<&T>

Returns a reference to the value if initialized.

pub fn call_once(&self, init: impl FnOnce() -> T) -> &T

Initializes the cell with init at most once and returns a reference to the stored value.

If another core is currently initializing, this method will spin until initialization completes.