Panic helpers for routing panic output to a sink and halting. Panic and halt helpers.
In many kernels you want a consistent strategy for panic handling:
- Format panic information to a device (serial/VGA/etc.).
- Halt the CPU (spin) to stop further damage.
This module provides the building blocks to implement that pattern.
Functions
- halt
- Busy-wait forever.
- panic_
to_ sink - Formats a
core::panic::PanicInfotosinkand then halts.